==> zio-aws-elasticbeanstalk_3-5.17.150.1-sources.jar: zio/aws/elasticbeanstalk/model/LaunchTemplate.scala <==
package zio.aws.elasticbeanstalk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.elasticbeanstalk.model.primitives.ResourceId
import scala.jdk.CollectionConverters.*
final case class LaunchTemplate(id: Option[ResourceId] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate = {
    import LaunchTemplate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
      .builder()
      .optionallyWith(
        id.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.id)
      .build()
  }
  def asReadOnly: zio.aws.elasticbeanstalk.model.LaunchTemplate.ReadOnly =
    zio.aws.elasticbeanstalk.model.LaunchTemplate.wrap(buildAwsValue())
}
object LaunchTemplate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticbeanstalk.model.LaunchTemplate =
      zio.aws.elasticbeanstalk.model.LaunchTemplate(id.map(value => value))
    def id: Option[ResourceId]
    def getId: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
  ) extends zio.aws.elasticbeanstalk.model.LaunchTemplate.ReadOnly {
    override val id: Option[ResourceId] = scala
      .Option(impl.id())
      .map(value => zio.aws.elasticbeanstalk.model.primitives.ResourceId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
  ): zio.aws.elasticbeanstalk.model.LaunchTemplate.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticbeanstalk_3-6.20.103.1-sources.jar: zio/aws/elasticbeanstalk/model/LaunchTemplate.scala <==
package zio.aws.elasticbeanstalk.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.elasticbeanstalk.model.primitives.ResourceId
import scala.jdk.CollectionConverters.*
final case class LaunchTemplate(id: Optional[ResourceId] = Optional.Absent) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate = {
    import LaunchTemplate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
      .builder()
      .optionallyWith(
        id.map(value => ResourceId.unwrap(value): java.lang.String)
      )(_.id)
      .build()
  }
  def asReadOnly: zio.aws.elasticbeanstalk.model.LaunchTemplate.ReadOnly =
    zio.aws.elasticbeanstalk.model.LaunchTemplate.wrap(buildAwsValue())
}
object LaunchTemplate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticbeanstalk.model.LaunchTemplate =
      zio.aws.elasticbeanstalk.model.LaunchTemplate(id.map(value => value))
    def id: Optional[ResourceId]
    def getId: ZIO[Any, AwsError, ResourceId] =
      AwsError.unwrapOptionField("id", id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
  ) extends zio.aws.elasticbeanstalk.model.LaunchTemplate.ReadOnly {
    override val id: Optional[ResourceId] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => zio.aws.elasticbeanstalk.model.primitives.ResourceId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticbeanstalk.model.LaunchTemplate
  ): zio.aws.elasticbeanstalk.model.LaunchTemplate.ReadOnly = new Wrapper(impl)
}
